CanonicalJsonSaveCodec class

JSON codec that canonicalizes maps by sorting keys.

Inheritance

Constructors

CanonicalJsonSaveCodec()
Creates a canonical JSON codec.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(String raw) → Map<String, dynamic>
Decodes a JSON string into a JSON-safe map.
override
decodeBytes(List<int> bytes) → Map<String, dynamic>
Decodes UTF-8 bytes into a JSON-safe map.
inherited
encode(Map<String, dynamic> value) → String
Encodes a JSON-safe map to a canonical JSON string.
override
encodeBytes(Map<String, dynamic> value) → List<int>
Encodes value to UTF-8 bytes.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited